@@ -24,7 +24,8 @@ rgl.Sweave <- function(name, width, height, options, ...) {
   } 
 
   snapshotDone <- FALSE
-
+  
+  # stayOpen is used below in rgl.Sweave.off
   stayOpen <- isTRUE(options$stayopen)
 
   type <- options$outputtype
@@ -217,7 +218,7 @@ withPrivateSeed <- local({
       # Need to call this to make sure that the value of .Random.seed gets put
       # into R's internal RNG state. (Issue #1763)
 
-      # httpuv::getRNGState()
+      # httpuv::getRNGState() # nolint
     })
     
     expr
@@ -287,6 +288,14 @@ fns <- local({
       }
   }  
   
+  knit_print.rglOpen3d <- function(x, options, ...) {
+    print(x, ...)
+    if (getOption("rgl.printRglwidget", FALSE)) {
+      plotnum <<- plotnum + 1
+    }
+    invisible(x)
+  }
+  
   knit_print.rglId <- function(x, options, ...) {
     if (getOption("rgl.printRglwidget", FALSE))	{
       scene <- scene3d()
@@ -312,16 +321,16 @@ fns <- local({
     }, logical(1))
   
   # move plots before source code
-  fig_before_code = function(x) {
-    s = vapply(x, evaluate::is.source, logical(1))
+  fig_before_code <- function(x) {
+    s <- vapply(x, evaluate::is.source, logical(1))
     if (length(s) == 0 || !any(s)) return(x)
-    s = which(s)
-    f = which(find_figs(x))
-    f = f[f >= min(s)]  # only move those plots after the first code block
+    s <- which(s)
+    f <- which(find_figs(x))
+    f <- f[f >= min(s)]  # only move those plots after the first code block
     for (i in f) {
-      j = max(s[s < i])
-      tmp = x[i]; x[[i]] = NULL; x = append(x, tmp, j - 1)
-      s = which(vapply(x, evaluate::is.source, logical(1)))
+      j <- max(s[s < i])
+      tmp <- x[i]; x[[i]] <- NULL; x <- append(x, tmp, j - 1)
+      s <- which(vapply(x, evaluate::is.source, logical(1)))
     }
     x
   }
@@ -439,8 +448,8 @@ fns <- local({
   # These functions are closely based on code from knitr:
   
   # compare two recorded plots
-  is_low_change = function(p1, p2) {
-    p1 = p1[[1]]; p2 = p2[[1]]  # real plot info is in [[1]],
+  is_low_change <- function(p1, p2) {
+    p1 <- p1[[1]]; p2 <- p2[[1]]  # real plot info is in [[1]],
                                 # as is plotnum
     if (length(p2) < (n1 <- length(p1))) return(FALSE)  # length must increase
     identical(p1[1:n1], p2[1:n1])
@@ -452,9 +461,9 @@ fns <- local({
     i1 <- idx[1]; i2 <- idx[2]  # compare plots sequentially
     for (i in 1:(n - 1)) {
       # remove the previous plot and move its index to the next plot
-      if (is_low_change(x[[i1]], x[[i2]])) m = c(m, i1)
-      i1 = idx[i + 1]
-      i2 = idx[i + 2]
+      if (is_low_change(x[[i1]], x[[i2]])) m <- c(m, i1)
+      i1 <- idx[i + 1]
+      i2 <- idx[i + 2]
     }
     if (is.null(m)) x else x[-m]
   }
@@ -464,7 +473,8 @@ fns <- local({
        hook_figkeep = hook_figkeep,
        hook_figshow = hook_figshow,
        hook_figbeforecode = hook_figbeforecode,
-       knit_print.rglId = knit_print.rglId)
+       knit_print.rglId = knit_print.rglId,
+       knit_print.rglOpen3d = knit_print.rglOpen3d)
 })
 
 setupKnitr <- fns[["setupKnitr"]]
@@ -473,6 +483,7 @@ hook_figkeep <- fns[["hook_figkeep"]]
 hook_figshow <- fns[["hook_figshow"]]
 hook_figbeforecode <- fns[["hook_figbeforecode"]]
 knit_print.rglId <- fns[["knit_print.rglId"]]
+knit_print.rglOpen3d <- fns[["knit_print.rglOpen3d"]]
 rm(fns)
 
 figWidth <- function() 
