@@ -9,6 +9,8 @@
 ##
 
 rgl.useNULL <- function() {
+  if (noOpenGL)
+    return(TRUE)
   opt <- getOption("rgl.useNULL", Sys.getenv("RGL_USE_NULL"))
   if (is.logical(opt)) return(opt)
   opt <- as.character(opt)
@@ -101,8 +103,7 @@ rgl.set <- function(which, silent = FALSE) {
 ##
 ##
 
-rgl.snapshot <- function( filename, fmt="png", top=TRUE )
-{
+rgl.snapshot <- function( filename, fmt="png", top=TRUE ) {
   if (top) rgl.bringtotop()
   
   idata <- as.integer(rgl.enum.pixfmt(fmt))
@@ -124,8 +125,7 @@ rgl.snapshot <- function( filename, fmt="png", top=TRUE )
 ##
 ##
 
-rgl.postscript <- function( filename, fmt="eps", drawText=TRUE )
-{
+rgl.postscript <- function( filename, fmt="eps", drawText=TRUE ) {
   idata <- as.integer(c(rgl.enum.gl2ps(fmt), as.logical(drawText)))
   if (length(filename) != 1)
     stop("filename is length ", length(filename))
@@ -144,8 +144,7 @@ rgl.postscript <- function( filename, fmt="eps", drawText=TRUE )
 ##
 ##
 
-rgl.pixels <- function(component = c("red", "green", "blue"), viewport = par3d("viewport"), top=TRUE )
-{
+rgl.pixels <- function(component = c("red", "green", "blue"), viewport = par3d("viewport"), top=TRUE ) {
   if (top) rgl.bringtotop()
   
   compnum <- as.integer(sapply(component, rgl.enum.pixelcomponent))
