@@ -276,12 +276,14 @@ Subscene* Scene::setCurrentSubscene(Subscene* subscene)
 
 void Scene::setupLightModel()
 {
+#ifndef RGL_NO_OPENGL
   Color global_ambient(0.0f,0.0f,0.0f,1.0f);
 
   glLightModelfv(GL_LIGHT_MODEL_AMBIENT, global_ambient.data );
   glLightModeli(GL_LIGHT_MODEL_LOCAL_VIEWER, GL_TRUE );
   glLightModeli(GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE );
   SAVEGLERROR;  
+#endif
 }
   
 void Scene::update(RenderContext* renderContext)
@@ -291,7 +293,7 @@ void Scene::update(RenderContext* renderContext)
 
 void Scene::render(RenderContext* renderContext)
 {
-
+#ifndef RGL_NO_OPENGL
   //
   // CLEAR BUFFERS
   //
@@ -332,6 +334,7 @@ void Scene::render(RenderContext* renderContext)
 
   rootSubscene.render(renderContext, true);  // All opaque stuff
   rootSubscene.render(renderContext, false); // non-opaque stuff
+#endif
 }
 
 
